{% extends 'base.html' %}
{% load i18n %}

{% block content %}

<h1>{% translate "mail sent" %}</h1>
<p>{% translate "You should receive shortly an e-mail with a link to change your password" %}</p>

{% endblock %}
