.euro, .nombre { font-family: 'Source Code Pro', monospace; text-align: right; }
.euro:after { content: ' €'; }
.at:after { content: '@'; }
.dot:after { content: '.'; }
dt { text-align: right; }
.smcp {
  -moz-font-feature-settings: 'smcp';
  -webkit-font-feature-settings: 'smcp';
  -o-font-feature-settings: 'smcp';
  font-feature-settings: 'smcp';
}
